@@ -25,6 +25,7 @@
 #include "version.h"
 
 #include "config.h"
+#include "configfile.h"
 
 namespace OCC {
 
@@ -75,6 +76,11 @@ QUrlQuery Updater::getQueryParams()
         // to beta channel
     }
 
+    // updateSegment (see configfile.h)
+    ConfigFile cfg;
+    auto updateSegment = cfg.updateSegment();
+    query.addQueryItem(QLatin1String("updatesegment"), QString::number(updateSegment));
+
     return query;
 }
 
